@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -16,8 +16,8 @@
   MagickWand image Methods.
 */
 
-#ifndef _MAGICKWAND_MAGICK_IMAGE_H
-#define _MAGICKWAND_MAGICK_IMAGE_H
+#ifndef MAGICKWAND_MAGICK_IMAGE_H
+#define MAGICKWAND_MAGICK_IMAGE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
